@@ -20,23 +20,34 @@ def dictinct_list(l, _sorted=False, key=None):
 
 
 def setAttr(o, name, value):
+    if not isinstance(o, dict):
+        return o
+
     o[name] = value
     return o
 
 
 def delAttr(o, name):
+    if not isinstance(o, dict):
+        return o
+
     if name in o:
         del o[name]
         return True
     else:
         return False
 
+
 def delAttr1(o, name):
-    if name in o:
-        del o[name]
+    if not isinstance(o, dict):
         return o
+
+    _o = o.copy()
+    if name in _o:
+        del _o[name]
+        return _o
     else:
-        return o
+        return _o
 
 
 def isEmptyDict(dictionary):
