@@ -6,7 +6,6 @@ from isc_common.json import BytesToJson
 
 logger = logging.getLogger(__name__)
 
-
 class RequestData:
     def __init__(self, _dict=None, request=None):
         if request:
@@ -48,65 +47,64 @@ class DSRequest(RPCRequest):
     enabledAll = None
     enddate = None
     endRow = None
+    json = None
     startRow = None
     tag = None
-    user = None
+    httpHeaders = None
     visibleMode = 'none'
 
-    def check_old(self, request):
+    _user = None
+
+    @property
+    def user(self):
         from isc_common.auth.models.user import User
-        if self.user == None:
-            self.username = request.session._session.get('username')
-            self.user_id = request.session._session.get('user_id')
+        if self._user == None:
+            if self.httpHeaders != None and self.httpHeaders.USER_ID:
+                self._user = User.objects.get(id=self.httpHeaders.USER_ID)
+                return self._user
+            else:
+                raise Exception('user not enable type')
+        return self._user
 
-            try:
-                self.ws_channel = request.GET.get('ws_channel')
-                self.ws_port = request.GET.get('ws_port')
-                self.host = request.GET.get('host')
+    @property
+    def user_id(self):
+        return self.user.id
 
-                if self.user_id == None:
-                    self.user_id = request.GET.get('user_id')
+    @property
+    def fio(self):
+        return self.user.get_short_name
 
-                if self.user_id == None and self.ws_channel != None:
-                    self.user_id = User.objects.get(username=self.ws_channel.split('_')[1]).id
-                if self.user_id != None:
-                    self.user = User.objects.get(id=self.user_id)
-                    self.is_admin = self.user.is_admin
-                    self.is_develop = self.user.is_develop
-                else:
-                    self.user = None
-            except User.DoesNotExist:
-                self.user = None
+    @property
+    def username(self):
+        return self.user.username
 
-            if self.is_admin == None:
-                self.is_admin = request.session._session.get('is_admin')
+    @property
+    def is_admin(self):
+        return self.user.is_admin
 
-            if self.is_develop == None:
-                self.is_develop = request.session._session.get('is_develop')
+    @property
+    def is_develop(self):
+        return self.user.is_develop
 
-            if self.ws_channel == None:
-                self.ws_channel = request.session._session.get('ws_channel')
-
-            if self.ws_port == None:
-                self.ws_port = request.session._session.get('ws_port')
-
-            if self.host == None:
-                self.host = request.session._session.get('host')
+    def set_user_data(self, user):
+        from isc_common.auth.models.user import User
+        if isinstance(user, int):
+            self._user = User.objects.get(id=user)
+        elif isinstance(user, str):
+            self._user = User.objects.get(username=user)
+        else:
+            raise Exception('user not enable type')
 
     def __init__(self, request):
-        from isc_common.auth.models.user import User
-
-        self.json = None
-
-        if request != None:
-            if request.body != b'':
-                self.json = BytesToJson(request.body)
 
+        if request != None and request.body != b'':
+            self.json = BytesToJson(request.body)
+            if isinstance(self.json, dict) and len(self.json) > 0:
                 data = self.json.get('data')
-                self.user = None
                 if isinstance(data, dict):
                     httpHeaders = data.get('httpHeaders')
                     if isinstance(httpHeaders, dict):
+
                         if httpHeaders.get('WS_CHANNEL') != None:
                             self.ws_channel = httpHeaders.get('WS_CHANNEL')
 
@@ -117,24 +115,23 @@ class DSRequest(RPCRequest):
                             self.host = httpHeaders.get('HOST')
 
                         if httpHeaders.get('USERNAME') != None:
-                            self.username = httpHeaders.get('USERNAME')
+                            self.set_user_data(user=httpHeaders.get('USERNAME'))
 
                         if httpHeaders.get('USER_ID') != None:
-                            # print(f'''USER_ID: {httpHeaders.get('USER_ID')}''')
-                            self.user_id = httpHeaders.get('USER_ID')
-                            self.user = User.objects.get(id=self.user_id)
-
-                        if httpHeaders.get('IS_ADMIN') != None:
-                            self.is_admin = httpHeaders.get('IS_ADMIN')
-
-                        if httpHeaders.get('IS_DEVELOP') != None:
-                            self.is_develop = httpHeaders.get('IS_DEVELOP')
+                            self.set_user_data(user=httpHeaders.get('USER_ID'))
 
                         delAttr(self.json.get('data'), 'httpHeaders')
-
-                self.check_old(request=request)
-            else:
-                self.check_old(request=request)
+                    else:
+                        if data.get('user_id') != None:
+                            self.set_user_data(user=data.get('user_id'))
+                else:
+                    login = self.json.get('login')
+                    if login != None:
+                        self.set_user_data(user=login)
+                    else:
+                        httpHeaders = self.json.get('httpHeaders')
+                        if httpHeaders != None:
+                            self.set_user_data(user=httpHeaders.get('USER_ID'))
 
         RPCRequest.__init__(self, self.json)
 
