@@ -10,7 +10,7 @@ from django.db.models import QuerySet, Model
 from django.forms import model_to_dict
 from websocket import create_connection
 
-from isc_common import setAttr
+from isc_common import setAttr, Wrapper
 from isc_common.common.functions import Common
 from isc_common.http.DSRequest import RequestData, DSRequest
 from isc_common.http.RPCResponse import RPCResponse, RPCResponseConstant
@@ -23,6 +23,35 @@ class Exception_WS_Enabled(Exception):
     pass
 
 
+class BodyWrapper(Wrapper):
+    data = None
+    login = None
+    json = None
+    httpHeaders = None
+
+
+class Body:
+    def __init__(self, body):
+        if not isinstance(body, dict):
+            raise Exception('body must by dict')
+
+        self.body = BodyWrapper(**body)
+        if self.body.httpHeaders != None:
+            self.body.httpHeaders = Wrapper(**self.body.httpHeaders)
+        elif self.body.data != None and self.body.data.get('httpHeaders') != None:
+            self.body.httpHeaders = Wrapper(**self.body.data.get('httpHeaders'))
+
+    @property
+    def login(self):
+        from isc_common.auth.models.user import User
+
+        if self.body.login != None:
+            return self.body.login
+        elif self.body.httpHeaders.USER_ID:
+            return User.objects.get(id=self.body.httpHeaders.USER_ID).username
+        else:
+            raise Exception('user not enable type')
+
 def JsonWSResponseWithException(printing=False, printing_res=False):
     try:
         class JE:
@@ -47,38 +76,31 @@ def JsonWSResponseWithException(printing=False, printing_res=False):
                 print("\n")
 
             def __call__(self, *args, **kwargs):
+                from isc_common.json import BytesToJson
                 request = args[0]
 
                 self.port = request.GET.get('ws_port')
-                if not self.port:
+                if self.port == None:
                     self.port = request.GET.get('port')
-                    if not self.port:
-                        self.port = request.session._session.get('ws_port')
-                        if not self.port:
-                            self.port = settings.WS_PORT
-                            if not self.port:
-                                raise Exception_WS_Enabled(Common.arraund_error('Do not have ws_port'))
+                    if self.port == None:
+                        self.port = settings.WS_PORT
+                        if self.port == None:
+                            raise Exception_WS_Enabled(Common.arraund_error('Do not have ws_port'))
 
                 self.host = request.GET.get('ws_host')
-                if not self.host:
+                if self.host == None:
                     self.host = request.GET.get('host')
-                    if not self.host:
-                        self.host = request.session._session.get('host')
-                        if not self.host:
-                            self.host = settings.WS_HOST
-                            if not self.host:
-                                raise Exception_WS_Enabled(Common.arraund_error('Do not have ws_host'))
+                    if self.host == None:
+                        self.host = settings.WS_HOST
+                        if self.host == None:
+                            raise Exception_WS_Enabled(Common.arraund_error('Do not have ws_host'))
 
                 self.channel = request.GET.get('ws_channel')
-                if not self.channel:
-                    self.channel = request.session._session.get('ws_channel')
-                    if not self.channel:
-                        body = request.body.decode('utf8').replace("'", '"')
-                        body = json.loads(body)
-                        if settings.WS_CHANNEL != None and body.get('login') != None:
-                            self.channel = f'''{settings.WS_CHANNEL}_{body.get('login')}'''
-                        else:
-                            raise Exception_WS_Enabled(Common.arraund_error('Do not have ws_channel'))
+                if self.channel == None:
+                    body = BytesToJson(request.body)
+                    body = Body(body)
+                    if settings.WS_CHANNEL != None:
+                        self.channel = f'''{settings.WS_CHANNEL}_{body.login}'''
 
                 try:
                     if printing:
@@ -204,25 +226,29 @@ def JsonWSPostResponseWithException(printing=False, printing_res=False):
             print("\n")
 
         def __call__(self, *args, **kwargs):
+            from isc_common.json import BytesToJson
             request = args[0]
 
             self.port = request.POST.get('ws_port')
-            if not self.port:
-                self.port = request.session._session.get('ws_port')
+            if self.port == None:
+                self.host = settings.WS_PORT
                 if not self.port:
                     raise Exception(Common.arraund_error('Do not have ws_port'))
 
             self.host = request.POST.get('ws_host')
-            if not self.host:
-                self.host = request.session._session.get('host')
+            if self.host == None:
+                self.host = settings.WS_HOST
                 if not self.host:
                     raise Exception(Common.arraund_error('Do not have ws_host'))
 
             self.channel = request.POST.get('ws_channel')
-            if not self.channel:
-                self.channel = request.session._session.get('ws_channel')
-                if not self.channel:
-                    raise Exception(Common.arraund_error('Do not have ws_channel'))
+            if self.channel == None:
+                body = BytesToJson(request.body)
+                body = Body(body)
+                if settings.WS_CHANNEL != None:
+                    self.channel = f'''{settings.WS_CHANNEL}_{body.login}'''
+                    if self.channel == None:
+                        raise Exception(Common.arraund_error('Do not have ws_channel'))
 
             try:
                 if printing:
