@@ -1,6 +1,6 @@
 class RPCRequest:
     def __init__(self, _dict):
-        if _dict:
+        if isinstance(_dict, dict):
             for key, value in _dict.items():
                 if isinstance(value, (list, tuple)):
                     setattr(self, key, [RPCRequest(x) if isinstance(x, dict) else x for x in value])
