@@ -107,19 +107,10 @@ class AuditModel(Model):
     class Meta:
         abstract = True
 
-    # def delete(self):
-    #     super().delete()
-
-    def delete_soft(self):
+    def soft_delete(self):
         self.deleted_at = timezone.now()
         self.save()
 
-    def soft_delete(self):
-        self.delete_soft()
-
-    def hard_delete(self):
-        super().delete()
-
     objects = AuditManager()
     all_objects = AuditManager(alive_only=False)
 
